From d76014681e8ea81e0cc9ba7fe91fe2cd0cc60f16 Mon Sep 17 00:00:00 2001
From: Amir MOHAMMADI <amir.mohammadi@idiap.ch>
Date: Thu, 30 Sep 2021 15:41:53 +0200
Subject: [PATCH] Use the conda-forge channel instead of the defaults channel

---
 bob/devtools/bootstrap.py  | 6 ++++--
 bob/devtools/build.py      | 4 ++--
 bob/devtools/scripts/ci.py | 2 +-
 doc/templates.rst          | 6 +++---
 4 files changed, 10 insertions(+), 8 deletions(-)

diff --git a/bob/devtools/bootstrap.py b/bob/devtools/bootstrap.py
index c7776670..58afb2cd 100644
--- a/bob/devtools/bootstrap.py
+++ b/bob/devtools/bootstrap.py
@@ -361,7 +361,7 @@ def get_channels(
     ]
 
     if add_dependent_channels:
-        channels += ["defaults", "conda-forge"]
+        channels += ["conda-forge"]
 
     return channels, upload_channel
 
@@ -526,11 +526,13 @@ if __name__ == "__main__":
         # clean conda cache and packages before building
         run_cmdline([conda_bin, "clean", "--all"])
 
-        # simple - just use the defaults channels when self building
+        # Just use the conda-forge channels when self building
         run_cmdline(
             [conda_bin, "install", "--yes"]
             + conda_verbosity
             + [
+                "-c",
+                "conda-forge",
                 "-n",
                 "base",
                 "python",
diff --git a/bob/devtools/scripts/ci.py b/bob/devtools/scripts/ci.py
index 87ee623f..d0c1ca56 100644
--- a/bob/devtools/scripts/ci.py
+++ b/bob/devtools/scripts/ci.py
@@ -78,7 +78,7 @@ Examples:
 @verbosity_option()
 @bdt.raise_on_error
 def base_deploy(dry_run):
-    """Deploys dependencies not available at the defaults channel.
+    """Deploys dependencies to our public channel
 
     Deployment happens to our public channel directly, as these are
     dependencies are required for proper bob/beat package runtime
diff --git a/doc/templates.rst b/doc/templates.rst
index 739cc2e7..2a27a0dd 100644
--- a/doc/templates.rst
+++ b/doc/templates.rst
@@ -409,7 +409,7 @@ New unexisting dependencies
 ===========================
 
 If your package depends on **third-party packages** (not Bob_ or BEAT_ existing
-resources) that are not in the CI, but exist on the conda ``defaults`` channel,
+resources) that are not in the CI, but exist on the ``conda-forge`` channel,
 you should perform some extra steps:
 
 1. Update ``conda_build_config.yaml`` in
@@ -486,10 +486,10 @@ environment with all ``bob`` dependencies:
 
 .. code-block:: bash
 
-  conda create -n bob_deps --dry-run --override-channels \\
+  conda create -n bob_deps --dry-run --override-channels --strict-channel-priority \\
   -c http://www.idiap.ch/software/bob/conda/label/beta \\
   -c http://www.idiap.ch/software/bob/conda \\
-  -c defaults
+  -c conda-forge
   click-plugins cmake coverage dask ... [all bob dependencies]
 
 The versions solved by ``conda`` should be the newest compatible ones you can
diff --git a/bob/devtools/build.py b/bob/devtools/build.py
index 92c27960..45ca6acb 100644
--- a/bob/devtools/build.py
+++ b/bob/devtools/build.py
@@ -613,10 +613,10 @@ def base_build(
     condarc_options,
 ):
     """Builds a non-beat/non-bob software dependence that doesn't exist on
-    defaults.
+    conda-forge.
 
     This function will build a software dependence that is required for our
     software stack, but does not (yet) exist on the defaults channels.  It first
     check if the build should run for the current architecture, checks if the
     package is not already built on our public channel and, if that is true, then
     proceeds with the build of the dependence.
@@ -613,10 +613,10 @@ def base_build(
 
     This function will build a software dependence that is required for our
-    software stack, but does not (yet) exist on the defaults channels.  It first
+    software stack, but does not (yet) exist on the conda-forge channels.  It first
     check if the build should run for the current architecture, checks if the
     package is not already built on our public channel and, if that is true, then
-- 
GitLab